@@ -8,6 +8,8 @@ from .._impl import (
     api_rids_EventRid as EventRid,
     api_rids_NominalDataSourceOrDatasetRid as NominalDataSourceOrDatasetRid,
     api_rids_NominalDataSourceRid as NominalDataSourceRid,
+    api_rids_ProcedureExecutionRid as ProcedureExecutionRid,
+    api_rids_ProcedureRid as ProcedureRid,
     api_rids_SegmentRid as SegmentRid,
     api_rids_StreamingConnectionRid as StreamingConnectionRid,
     api_rids_VideoFileRid as VideoFileRid,
@@ -24,6 +26,8 @@ __all__ = [
     'EventRid',
     'NominalDataSourceOrDatasetRid',
     'NominalDataSourceRid',
+    'ProcedureExecutionRid',
+    'ProcedureRid',
     'SegmentRid',
     'StreamingConnectionRid',
     'VideoFileRid',
