@@ -100,6 +100,9 @@ from .._impl import (
     scout_chartdefinition_api_PlotlyPanelDefinitionVisitor as PlotlyPanelDefinitionVisitor,
     scout_chartdefinition_api_PlotlyPreset as PlotlyPreset,
     scout_chartdefinition_api_Position as Position,
+    scout_chartdefinition_api_ProcedureVizDefinition as ProcedureVizDefinition,
+    scout_chartdefinition_api_ProcedureVizDefinitionV1 as ProcedureVizDefinitionV1,
+    scout_chartdefinition_api_ProcedureVizDefinitionVisitor as ProcedureVizDefinitionVisitor,
     scout_chartdefinition_api_RangeCellConfig as RangeCellConfig,
     scout_chartdefinition_api_RangeGroupBySort as RangeGroupBySort,
     scout_chartdefinition_api_RangeGroupBySortVisitor as RangeGroupBySortVisitor,
@@ -258,6 +261,9 @@ __all__ = [
     'PlotlyPanelDefinitionV1',
     'PlotlyPreset',
     'Position',
+    'ProcedureVizDefinition',
+    'ProcedureVizDefinitionVisitor',
+    'ProcedureVizDefinitionV1',
     'RangeCellConfig',
     'RangeGroupBySort',
     'RangeGroupBySortVisitor',
