@@ -5,6 +5,8 @@ from .._impl import (
     timeseries_archetype_api_BatchGetSeriesArchetypeResponse as BatchGetSeriesArchetypeResponse,
     timeseries_archetype_api_BigQueryLocatorTemplate as BigQueryLocatorTemplate,
     timeseries_archetype_api_CreateSeriesArchetypeRequest as CreateSeriesArchetypeRequest,
+    timeseries_archetype_api_CsvLocatorTemplate as CsvLocatorTemplate,
+    timeseries_archetype_api_CsvLocatorV2Template as CsvLocatorV2Template,
     timeseries_archetype_api_Influx1LocatorTemplate as Influx1LocatorTemplate,
     timeseries_archetype_api_Influx2LocatorTemplate as Influx2LocatorTemplate,
     timeseries_archetype_api_LocatorTemplate as LocatorTemplate,
@@ -18,3 +20,24 @@ from .._impl import (
     timeseries_archetype_api_VisualCrossingLocatorTemplate as VisualCrossingLocatorTemplate,
 )
 
+__all__ = [
+    'BatchCreateSeriesArchetypeRequest',
+    'BatchGetSeriesArchetypeRequest',
+    'BatchGetSeriesArchetypeResponse',
+    'BigQueryLocatorTemplate',
+    'CreateSeriesArchetypeRequest',
+    'CsvLocatorTemplate',
+    'CsvLocatorV2Template',
+    'Influx1LocatorTemplate',
+    'Influx2LocatorTemplate',
+    'LocatorTemplate',
+    'LocatorTemplateVisitor',
+    'NominalLocatorTemplate',
+    'SeriesArchetype',
+    'SeriesArchetypeName',
+    'TimescaleDbLocatorTemplate',
+    'TimestreamLocatorTemplate',
+    'UpdateSeriesArchetypeMetadataRequest',
+    'VisualCrossingLocatorTemplate',
+]
+
